.. _user_guide:

User guide
==========

.. toctree::

    quick_tutorial

    fundamentals/index.rst
    polynomial/index.rst
    main_usage/index.rst
    advanced_topics/index.rst

    zbibliography
